==> red5pro-0.0.14.tar.gz: ios/Classes/Red5StreamView.m <==
//
//  Red5StreamView.m
//  red5pro
//
//  Created by Jaydip Godhani on 22/11/21.
//

#import "Red5StreamView.h"
#import "Red5ProStreamController.h"

@implementation Red5StreamView {
    UIView *_view;
    
    NSString *strBitrate;
    double fps;
    double frameWidth;
    double frameHeight;
    
    NSString *strContextName;
    NSString *strHostName;
    NSString *strLicencekey;
    NSString *strPort;
    NSInteger protocol;
    
    Red5ProStreamController *controller;
    
}

- (instancetype)initWithFrame:(CGRect)frame
               viewIdentifier:(int64_t)viewId
                    arguments:(id _Nullable)args
              binaryMessenger:(NSObject<FlutterBinaryMessenger>*)messenger {
    NSDictionary *dictArgs = (NSDictionary *)args;
    strBitrate = [dictArgs valueForKey:@"bitrate"];
    fps = [[dictArgs valueForKey:@"fps"] doubleValue];
    frameWidth = [[dictArgs valueForKey:@"width"] doubleValue];
    frameHeight = [[dictArgs valueForKey:@"height"] doubleValue];
    
    strContextName = [dictArgs valueForKeyPath:@"configuration.contextName"];
    strHostName = [dictArgs valueForKeyPath:@"configuration.host"];
    strLicencekey = [dictArgs valueForKeyPath:@"configuration.licenseKey"];
    strPort = [dictArgs valueForKeyPath:@"configuration.port"];
    protocol = [[dictArgs valueForKeyPath:@"configuration.protocol"] integerValue];
    
  if (self = [super init]) {
      _view = [[UIView alloc] init];
      
      controller = [[Red5ProStreamController alloc] init];
      //controller.view.frame = CGRectMake(0, 0, frameWidth, frameHeight);
      _view.frame = controller.view.frame;
      controller.strBitrate = strBitrate;
      controller.fps = fps;
      controller.frameWidth = frameWidth;
      controller.frameHeight = frameHeight;
      controller.strContextName = strContextName;
      controller.strHostName = strHostName;
      controller.strLicencekey = strLicencekey;
      controller.strPort = strPort;
      controller.protocol = protocol;
      controller.viewId = viewId;
      [controller setupConfiguration];
      [self.view addSubview:controller.view];
      
      NSString *strHandlerChannelName = [NSString stringWithFormat:@"Red5StreamView/%lld",viewId];
      FlutterMethodChannel* channel = [FlutterMethodChannel methodChannelWithName:strHandlerChannelName binaryMessenger:messenger];
      [channel setMethodCallHandler:^(FlutterMethodCall * _Nonnull call, FlutterResult  _Nonnull result) {
          if ([call.method isEqualToString:@"switchCamera"]) {
              [self->controller switchCamera];
              result(@(YES));
          } else if ([call.method isEqualToString:@"isPublishing"]) {
              result(@(self->controller.isPublishing));
          } else if ([call.method isEqualToString:@"startStreaming"]) {
              NSDictionary *dictArgument = (NSDictionary *)call.arguments;
              NSString *streamKey = [dictArgument valueForKey:@"streamKey"];
              if (streamKey != nil && ![streamKey isEqualToString:@""]) {
                  if (self->controller.isPublishing == false) {
                      int recordType = [[dictArgument valueForKey:@"recordType"] intValue];
                      [self->controller startStreaming:streamKey type:recordType];
                      result(@(YES));
                  } else {
                      FlutterError *error = [FlutterError errorWithCode:@"ALREADY_PUBLISHING" message:@"Already stream published" details:@""];
                      result(error);
                  }
              } else {
                  FlutterError *error = [FlutterError errorWithCode:@"INVALID_PARAMETER" message:@"StreamKey and Type should not be null" details:@""];
                  result(error);
              }
          } else if ([call.method isEqualToString:@"stopStreaming"]) {
              if (self->controller.isPublishing) {
                  [self->controller stopStreaming];
                  result(@(YES));
              } else {
                  FlutterError *error = [FlutterError errorWithCode:@"NOT_LIVE_STREAM" message:@"Stream is not live" details:@""];
                  result(error);
              }
          }
      }];
  }
  return self;
}
- (UIView*)view {
  return _view;
}

@end

==> red5pro-0.0.21.tar.gz: ios/Classes/Red5StreamView.m <==
//
//  Red5StreamView.m
//  red5pro
//
//  Created by Jaydip Godhani on 22/11/21.
//

#import "Red5StreamView.h"
#import "Red5ProStreamController.h"

@implementation Red5StreamView {
    UIView *_view;
    
    NSString *strBitrate;
    double fps;
    double frameWidth;
    double frameHeight;
    
    NSString *strContextName;
    NSString *strHostName;
    NSString *strLicencekey;
    NSString *strPort;
    NSInteger protocol;
    
    Red5ProStreamController *controller;
    
}

- (instancetype)initWithFrame:(CGRect)frame
               viewIdentifier:(int64_t)viewId
                    arguments:(id _Nullable)args
              binaryMessenger:(NSObject<FlutterBinaryMessenger>*)messenger {
    NSDictionary *dictArgs = (NSDictionary *)args;
    strBitrate = [dictArgs valueForKey:@"bitrate"];
    fps = [[dictArgs valueForKey:@"fps"] doubleValue];
    frameWidth = [[dictArgs valueForKey:@"width"] doubleValue];
    frameHeight = [[dictArgs valueForKey:@"height"] doubleValue];
    
    strContextName = [dictArgs valueForKeyPath:@"configuration.contextName"];
    strHostName = [dictArgs valueForKeyPath:@"configuration.host"];
    strLicencekey = [dictArgs valueForKeyPath:@"configuration.licenseKey"];
    strPort = [dictArgs valueForKeyPath:@"configuration.port"];
    protocol = [[dictArgs valueForKeyPath:@"configuration.protocol"] integerValue];
    
  if (self = [super init]) {
      _view = [[UIView alloc] init];
      
      controller = [[Red5ProStreamController alloc] init];
      //controller.view.frame = CGRectMake(0, 0, frameWidth, frameHeight);
      _view.frame = controller.view.frame;
      controller.strBitrate = strBitrate;
      controller.fps = fps;
      controller.frameWidth = frameWidth;
      controller.frameHeight = frameHeight;
      
      controller.viewId = viewId;
      [controller setupConfiguration:false];
      [self.view addSubview:controller.view];
      
      NSString *strHandlerChannelName = [NSString stringWithFormat:@"Red5StreamView/%lld",viewId];
      FlutterMethodChannel* channel = [FlutterMethodChannel methodChannelWithName:strHandlerChannelName binaryMessenger:messenger];
      [channel setMethodCallHandler:^(FlutterMethodCall * _Nonnull call, FlutterResult  _Nonnull result) {
          if ([call.method isEqualToString:@"switchCamera"]) {
              [self->controller switchCamera];
              result(@(YES));
          } else if ([call.method isEqualToString:@"isPublishing"]) {
              result(@(self->controller.isPublishing));
          } else if ([call.method isEqualToString:@"startStreaming"]) {
              NSDictionary *dictArgument = (NSDictionary *)call.arguments;
              NSString *streamKey = [dictArgument valueForKey:@"streamKey"];
              
              self->strContextName = [dictArgument valueForKeyPath:@"configuration.contextName"];
              self->strHostName = [dictArgument valueForKeyPath:@"configuration.host"];
              self->strLicencekey = [dictArgument valueForKeyPath:@"configuration.licenseKey"];
              self->strPort = [dictArgument valueForKeyPath:@"configuration.port"];
              self->protocol = [[dictArgument valueForKeyPath:@"configuration.protocol"] integerValue];
              
              self->controller.strContextName = self->strContextName;
              self->controller.strHostName = self->strHostName;
              self->controller.strLicencekey = self->strLicencekey;
              self->controller.strPort = self->strPort;
              self->controller.protocol = self->protocol;
              [self->controller setupConfiguration:true];
              
              if (streamKey != nil && ![streamKey isEqualToString:@""]) {
                  if (self->controller.isPublishing == false) {
                      int recordType = [[dictArgument valueForKey:@"recordType"] intValue];
                      [self->controller startStreaming:streamKey type:recordType];
                      result(@(YES));
                  } else {
                      FlutterError *error = [FlutterError errorWithCode:@"ALREADY_PUBLISHING" message:@"Already stream published" details:@""];
                      result(error);
                  }
              } else {
                  FlutterError *error = [FlutterError errorWithCode:@"INVALID_PARAMETER" message:@"StreamKey and Type should not be null" details:@""];
                  result(error);
              }
          } else if ([call.method isEqualToString:@"stopStreaming"]) {
              if (self->controller.isPublishing) {
                  [self->controller stopStreaming];
                  result(@(YES));
              } else {
                  FlutterError *error = [FlutterError errorWithCode:@"NOT_LIVE_STREAM" message:@"Stream is not live" details:@""];
                  result(error);
              }
          }
      }];
  }
  return self;
}
- (UIView*)view {
  return _view;
}

@end
